==> gammaray_2.0.1.orig.tar.xz: gammaray-2.0.1/core/tools/standardpaths/standardpaths.h <==
/*
  standardpaths.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_STANDARDPATHS_H
#define GAMMARAY_STANDARDPATHS_H

#include <core/toolfactory.h>

namespace GammaRay {

class StandardPaths : public QObject
{
  Q_OBJECT
  public:
    explicit StandardPaths(ProbeInterface *probe, QObject *parent = 0);
    ~StandardPaths();
};

class StandardPathsFactory : public QObject, public StandardToolFactory<QObject, StandardPaths>
{
  Q_OBJECT
  Q_INTERFACES(GammaRay::ToolFactory)
  public:
    explicit StandardPathsFactory(QObject *parent) : QObject(parent)
    {
    }

    virtual inline QString name() const
    {
      return tr("Standard Paths");
    }
};

}

#endif // GAMMARAY_STANDARDPATHS_H

==> gammaray_2.1.0.orig.tar.xz: gammaray-2.1.0/core/tools/standardpaths/standardpaths.h <==
/*
  standardpaths.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_STANDARDPATHS_STANDARDPATHS_H
#define GAMMARAY_STANDARDPATHS_STANDARDPATHS_H

#include "core/toolfactory.h"

namespace GammaRay {

class StandardPaths : public QObject
{
  Q_OBJECT
  public:
    explicit StandardPaths(ProbeInterface *probe, QObject *parent = 0);
    ~StandardPaths();
};

class StandardPathsFactory : public QObject, public StandardToolFactory<QObject, StandardPaths>
{
  Q_OBJECT
  Q_INTERFACES(GammaRay::ToolFactory)
  public:
    explicit StandardPathsFactory(QObject *parent) : QObject(parent)
    {
    }

    virtual inline QString name() const
    {
      return tr("Standard Paths");
    }
};

}

#endif // GAMMARAY_STANDARDPATHS_H
